Test - pydagoras
Description: Documentation of the pydagoras package

# Test

who knows additions

Lorem ipsum dolor sit amet, (1) consectetur adipiscing elit.

1. :man_raising_hand: I'm an annotation! I can contain `code`, formatted text, images, ... basically anything that can be expressed in Markdown.

The `range()` function is used to generate a sequence of numbers.

    theme:
      features:
        - content.code.annotate # (1)

1. :man_raising_hand: I'm a code annotation! I can contain `code`, formatted text, images, ... basically anything that can be written in Markdown.

eg.py
    10
    11
    12
    13
    14
    15
    16
    17
    import this

    def egfunc(i):
    theme:
      print (i) # (1)
      features:
        - content.code.annotate # (2)
        - content.code.annotate # (3)

1. comment x I'm a code annotation! I can contain `code`, __formatted
2. comment y I'm a code annotation! I can contain `code`, __formatted
3. comment z I'm a code annotation! I can contain `code`, __formatted